/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef rslthb
#define rslthb

#include <QGraphicsRectItem>
#include "con.h"

class QTextDocument;
class dbz;
class rsltb : public QGraphicsRectItem
<%
	public:
		rsltb(dbz*);
		~rsltb();

		int type() const <% return gratype(37); %>

		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
                QTextDocument *mgmozt;
                QTextCursor *meghat;
		bool kapni;

		qreal kapod;
		qreal mgzerz;

		void kitzjl(qreal, qreal);
		void bprl(QPointF hsztzk);
		void bprl(qreal kket, qreal fldlgz);

		int jlzpnt;

		dbz *kidlgz;

		void lmzdul(QFocusEvent*);
		void jvsltz();

		void keyPressEvent(QKeyEvent* mgmnkl);
		bool moveKey(QKeyEvent* mgmnkl);
		void keyReleaseEvent(QKeyEvent *mgmnkl);
		void inputMethodEvent(QInputMethodEvent *);
%>;

#endif 

